Addshore has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/268133

Change subject: Use LinkTarget in Revision::newFromTitle
......................................................................

Use LinkTarget in Revision::newFromTitle

Change-Id: Ib1c58c30106d535daa736feb17e9b9b76c1cf10e
---
M includes/Revision.php
1 file changed, 6 insertions(+), 6 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/33/268133/1

diff --git a/includes/Revision.php b/includes/Revision.php
index f4f6dca..e76d19e 100644
--- a/includes/Revision.php
+++ b/includes/Revision.php
@@ -101,22 +101,22 @@
 
        /**
         * Load either the current, or a specified, revision
         * that's attached to a given title. If not attached
         * to that title, will return null.
         *
         * $flags include:
         *      Revision::READ_LATEST  : Select the data from the master
         *      Revision::READ_LOCKING : Select & lock the data from the master
         *
-        * @param Title $title
+        * @param LinkTarget $linkTarget
         * @param int $id (optional)
         * @param int $flags Bitfield (optional)
         * @return Revision|null
         */
-       public static function newFromTitle( $title, $id = 0, $flags = 0 ) {
+       public static function newFromTitle( LinkTarget $linkTarget, $id = 0, 
$flags = 0 ) {
                $conds = array(
-                       'page_namespace' => $title->getNamespace(),
-                       'page_title' => $title->getDBkey()
+                       'page_namespace' => $linkTarget->getNamespace(),
+                       'page_title' => $linkTarget->getDBkey()
                );
                if ( $id ) {
                        // Use the specified ID
@@ -101,22 +101,22 @@
        /**
         * Load either the current, or a specified, revision
-        * that's attached to a given title. If not attached
-        * to that title, will return null.
+        * that's attached to a given link target. If not attached
+        * to that link target, will return null.
         *
         * $flags include:

-- 
To view, visit https://gerrit.wikimedia.org/r/268133
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Ib1c58c30106d535daa736feb17e9b9b76c1cf10e
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Addshore <[email protected]>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to